@@ -21,6 +21,11 @@ def word_level():
 	[dic.update({w:"awl"}) for w in word_awl.word_awl]
 	return dic
 
+def get_word_level(w): 
+	''' {"w":"awl", "w2": "gsl1", "e3":"gsl2"} '''
+	from dic import word_awl, word_gsl1, word_gsl2
+	return 'awl' if w in word_awl.word_awl else 'gsl1' if w in word_gsl1.word_gsl1 else 'gsl2' if w in word_gsl2.word_gsl2 else ''
+
 def readzip(name): # file endswith '.zip'
 	z = zipfile.ZipFile( pathlib.Path(__file__).parent / f"{name}.zip" , 'r') 
 	lines = z.read(z.namelist()[0]) #bytes 
@@ -34,7 +39,7 @@ loadset = lambda name="verblist": { w.strip() for w in readzip( name ) if w } #
 loadss = lambda name="ecdic": { line.split('\t')[0].strip():line.split('\t')[1].strip()  for line in readzip(name) if line } # s -> s , ecdic 
 
 if __name__ == '__main__':
-	print (dm_essay())
+	print (get_word_level('academic'))
 
 def word_map(chunk, idx , attr):  # by academic . | 1 | jj_to_nn 
 	toks = chunk.split()
