@@ -258,6 +258,34 @@ class util(object):
 		db.close()
 		print("finished:", infile, dbfile, "\t | using:", time.time() - start)
 
+	def load_doc(self, infile, dbfile): 
+		''' spider-all.json => spider.sqlite, doc(arr), spacybs,  2022.3.30 '''
+		print("started:", infile, dbfile,flush=True)
+		start = time.time()
+		db = Spacybs(dbfile)
+		db.conn.execute(f'drop TABLE IF EXISTS doc')
+		db.conn.execute(f'CREATE TABLE IF NOT EXISTS doc (arr MEDIUMTEXT)') # { filename, doc,  snts , 
+		db.execute(f'DROP TABLE IF EXISTS fts')
+		db.execute('''CREATE VIRTUAL TABLE if not exists fts USING fts5(sid, snt, terms, columnsize=0, detail=full,tokenize = "unicode61 remove_diacritics 0 tokenchars '-_'")''') #self.conn.execute('''CREATE VIRTUAL TABLE if not exists fts USING fts5(snt, terms, columnsize=0, detail=none,tokenize = "unicode61 remove_diacritics 0 tokenchars '-_'")''')
+
+		for line in readline(infile):
+			try:
+				line = line.strip()
+				if not line: continue
+				arr = json.loads(line)
+				rowid = int( arr['id'])
+				db.conn.execute(f"insert or ignore into doc(rowid, arr) values(?,?)", (rowid, line))
+				for idx, snt in enumerate(arr['snts']): 
+					doc = spacy.frombs(db[snt]) if snt in db else spacy.nlp(snt) 
+					kps = " ".join([ f"{t.pos_}_{t.lemma_}" for t in doc] + [ f"{t.tag_}_{t.lemma_}" for t in doc] + [ f"{t.dep_}_{t.head.pos_}_{t.pos_}_{t.head.lemma_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp')])
+					db.conn.execute(f"insert or ignore into fts(sid, snt,terms) values(?,?,?)", (f"{rowid}-{idx}", snt, kps ))
+			except Exception as ex:
+				print(">>ex:", ex,"\t|",line)
+
+		db.conn.commit()
+		db.close()
+		print("finished:", infile, dbfile, "\t | using:", time.time() - start)
+
 	def topika(self,dbfile, name=None, host='127.0.0.1', port=9311, db_bs=0, db_dm=5):  
 		''' clec.spacybs -> :  snt:clec(list) , {snt}:bs(hash),  2022.1.20 '''
 		import redis
